package com.dcs.hnyz.mapper;

import java.util.List;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.dcs.hnyz.domain.EquipmentParam;
import com.dcs.hnyz.domain.vo.EquipmentParamFormVO;

/**
 * 设备参数管理Mapper接口
 * 
 * @author hmy
 * @date 2025-04-23
 */
public interface EquipmentParamMapper extends BaseMapper<EquipmentParam>
{
    /**
     * 查询设备参数管理
     * 
     * @param registerId 设备参数管理主键
     * @return 设备参数管理
     */
    public EquipmentParam selectEquipmentParamByRegisterId(Long registerId);

    /**
     * 查询设备参数管理列表
     * 
     * @param equipmentParam 设备参数管理
     * @return 设备参数管理集合
     */
    public List<EquipmentParam> selectEquipmentParamList(EquipmentParam equipmentParam);

    /**
     * 新增设备参数管理
     * 
     * @param equipmentParam 设备参数管理
     * @return 结果
     */
    public int insertEquipmentParam(EquipmentParam equipmentParam);

    /**
     * 修改设备参数管理
     * 
     * @param equipmentParam 设备参数管理
     * @return 结果
     */
    public int updateEquipmentParam(EquipmentParam equipmentParam);

    /**
     * 删除设备参数管理
     * 
     * @param registerId 设备参数管理主键
     * @return 结果
     */
    public int deleteEquipmentParamByRegisterId(Long registerId);

    /**
     * 批量删除设备参数管理
     * 
     * @param registerIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteEquipmentParamByRegisterIds(Long[] registerIds);

    /**
     * 查询设备参数表单列表
     *
     * @param equipmentParam 设备参数管理
     * @return 设备参数管理集合
     */
    public List<EquipmentParamFormVO> selectEquipmentParamForm(EquipmentParam equipmentParam);
}
